@@ -27,6 +27,8 @@ import adagios.settings
 import time
 import adagios.status.utils
 from django.utils.translation import ugettext as _
+import socket
+
 
 class BusinessProcess(object):
 
@@ -658,8 +660,6 @@ class Service(BusinessProcess):
     def get_status(self):
         try:
             self.load()
-            if self._service.get('last_check') == 0:
-                self._service['state'] = 3
             return self._service.get('state', 3)
         except Exception, e:
             self.errors.append(e)
@@ -673,7 +673,7 @@ class Host(BusinessProcess):
 
     def load(self):
             self._livestatus = adagios.status.utils.livestatus(request=None)
-            self._host = self._livestatus.get_host(self.name)
+            self._host = self._livestatus.get_host(self.name, backend=None)
             self.display_name = self._host.get('display_name') or self.name
             self.notes = self._host.get(
                 'notes') or 'You are looking at the host %s' % self.name
@@ -718,11 +718,11 @@ class Domain(Host):
     def load(self):
         self._livestatus = adagios.status.utils.livestatus(request=None)
         try:
-            self._host = self._livestatus.get_host(self.name)
+            self._host = self._livestatus.get_host(self.name, backend=None)
         except IndexError:
             self.create_host()
             try:
-                self._host = self._livestatus.get_host(self.name)
+                self._host = self._livestatus.get_host(self.name, backend=None)
             except IndexError:
                 raise Exception(_("Failed to create host %s") % self.name)
 
@@ -741,9 +741,6 @@ class Domain(Host):
 
     def create_host(self):
         """ Create a new Host object in nagios config and reload nagios  """
-        import pynag.Model
-        import pynag.Control
-        import socket
         try:
             socket.gethostbyname(self.name)
         except Exception:
