@@ -37,7 +37,8 @@ $(document).ready(function() {
     // Multiselect checkboxes at the top-left of status-tables
     adagios.status.initilize_multiselect_checkboxes();
 
-
+    // Input boxes with the class pynag-autocomplete get select2 autocomplete magic.
+    adagios.objectbrowser.autocomplete_for_multichoicefields();
 
     // Fix console logging for internet explorer
     adagios.misc.internet_explorer_console_fix();
@@ -952,4 +953,45 @@ adagios.status.delete_downtime = function(object_type, downtime_id) {
     parameters['downtime_id'] = downtime_id;
     parameters['is_service'] = (object_type == 'host');
     return adagios.rest.status.delete_downtime(parameters);
+};
+
+
+// Reload current page in X seconds. (1000 = 1 second). Will not reload if user is
+// Interacting with the page. Any value < 0.01 will be ignored.
+adagios.misc.timed_reload = function(seconds) {
+    var milliseconds = seconds * 1000;
+    if (!seconds || milliseconds < 100) {
+        return;
+    }
+    var reload_function = function() { console.log("reloading..."); window.location.reload(); };
+    var reload = setInterval(reload_function, milliseconds);
+    var reload_has_been_canceled;
+    $( ".selectable").change(function(data) {
+        if (!reload_has_been_canceled) {
+            console.log("checkbox was changed. Canceling reload");
+            clearInterval(reload);
+        }
+
+    });
+    $("div .modal").on('shown', function(data) {
+        if (!reload_has_been_canceled) {
+            console.log("Canceling reload because of modal shown");
+            clearInterval(reload);
+        }
+    });
+    $("#search_field").keyup( function(data) {
+       if (!reload_has_been_canceled) {
+            console.log("Canceling reload because search_field was modified");
+            clearInterval(reload);
+        }
+    });
+};
+
+// Find all fields with the class pynag-autocomplete and turn them into proper select2 fields
+adagios.objectbrowser.autocomplete_for_multichoicefields = function() {
+    $("input.pynag-autocomplete").each(function() {
+        var choices = $(this).data()["choices"] || '';
+	    choices = choices.split(',');
+	    $(this).select2({tags:choices});
+    });
 };
\ No newline at end of file
