@@ -26,6 +26,7 @@ from django.utils.translation import ugettext as _
 
 import os.path
 from adagios import settings
+import adagios.utils
 from pynag import Model, Control
 from django.core.mail import EmailMultiAlternatives
 import pynag.Parsers
@@ -93,6 +94,21 @@ class ContactUsForm(forms.Form):
         """) % {'topic': topic, 'sender': sender, 'message': message}
         send_mail(subject, msg, from_address, to_address, fail_silently=False)
 
+class UserdataForm(forms.Form):
+    language = forms.ChoiceField(
+        choices=settings.LANGUAGES,
+        required=False
+    )
+    theme = forms.ChoiceField(
+        choices=[(x, x) for x in adagios.utils.get_available_themes()],
+        required=False
+    )
+    refresh_rate = forms.IntegerField(
+        help_text="For pages that auto-reload. Set the number of seconds to wait between page refreshes. "
+                  "Set refresh rate to 0 to disable automatic refreshing.",
+        required=False,
+    )
+
 
 class AdagiosSettingsForm(forms.Form):
     nagios_config = forms.CharField(
@@ -133,6 +149,17 @@ class AdagiosSettingsForm(forms.Form):
         help_text=_("Default coordinates when opening up the world map. This should be in the form of longitude,latitude"))
     map_zoom = forms.CharField(
         help_text=_("Default Zoom level when opening up the world map. 10 is a good default value"))
+    language = forms.ChoiceField(choices=settings.LANGUAGES, required=False)
+    theme = forms.ChoiceField(required=False, choices=[(x,x) for x in adagios.utils.get_available_themes()])
+    refresh_rate = forms.IntegerField(
+        help_text="For pages that auto-reload. Set the number of seconds to wait between page refreshes. "
+                  "Set refresh rate to 0 to disable automatic refreshing."
+    )
+    enable_pnp4nagios = forms.BooleanField(required=False, help_text="If set, include pnp4nagios graphs in status views")
+    enable_graphite = forms.BooleanField(required=False, help_text="If set, include graphite graphs in status views")
+    graphite_url = forms.CharField(help_text="Path to your graphite install.", required=False)
+    graphite_querystring = forms.CharField(help_text="Querystring that is passed into graphite's /render method. {host} is replaced with respective hostname while {host_} will apply common graphite escaping. i.e. example.com -> example_com", required=False)
+    graphite_title = forms.CharField(help_text="Use this title on all graphs coming from graphite", required=False)
     include = forms.CharField(
         required=False, help_text=_("Include configuration options from files matching this pattern"))
 
