@@ -55,6 +55,73 @@ HOST_NOTIFICATION_OPTIONS = (
 
 BOOLEAN_CHOICES = (('', 'not set'), ('1', '1'), ('0', '0'))
 
+class PynagAutoCompleteField(forms.CharField):
+    """ Behaves like Charfield, but includes data-choices for select2 autocomplete. """
+    def __init__(self, object_type, inline_help_text=None, complete="shortname", *args, **kwargs):
+        super(PynagAutoCompleteField, self).__init__(*args, **kwargs)
+
+        # Add help text into data-placeholder
+        if not inline_help_text:
+            inline_help_text = "Select some {object_type}s"
+            inline_help_text = inline_help_text.format(object_type=object_type)
+        self.widget.attrs['data-placeholder'] = inline_help_text
+
+        # Add autcomplete choices in data-choices
+        if complete == 'shortname':
+            choices = self.get_all_shortnames(object_type=object_type)
+        elif complete == 'name':
+            choices = self.get_all_object_names(object_type=object_type)
+        else:
+            raise ValueError("complete must be either shortname or name")
+        choices_string = ','.join(choices)
+        self.widget.attrs['data-choices'] = choices_string
+
+        # Give our widget a unique css class
+        self.widget.attrs['class'] = self.widget.attrs.get('class', '')
+        self.widget.attrs['class'] += ' pynag-autocomplete ';
+
+        # Hardcode widget length to 500px, because select2 plays badly
+        # with css
+        self.widget.attrs['style'] = self.widget.attrs.get('style', '')
+        self.widget.attrs['style'] += ' width: 500px; '
+
+    def get_all_shortnames(self, object_type):
+        """ Returns a list of all shortnames, given a specific object type."""
+        objects = self.get_all_objects(object_type)
+        shortnames = map(lambda x: x.get_shortname(), objects)
+
+        # Remove objects with no shortname
+        shortnames = filter(lambda x: x, shortnames)
+
+        return shortnames
+    def get_all_object_names(self, object_type):
+        """ Returns a list of all object names (name attribute) for a given object type. """
+        objects = self.get_all_objects(object_type)
+        names = map(lambda x: x.name, objects)
+
+        # Remove objects with no name
+        names = filter(lambda x: x, names)
+        return names
+
+    def get_all_objects(self, object_type):
+        """ Returns all object of a given object type """
+        Class = Model.string_to_class[object_type]
+        objects = Class.objects.get_all()
+        return objects
+
+    def prepare_value(self, value):
+        """
+        Takes a comma separated string, removes + if it is prefixed so. Returns a comma seperated string
+        """
+        if value == 'null':
+            return value
+        elif isinstance(value, basestring):
+            a = AttributeList(value)
+            self.__prefix = a.operator
+            a.operator = ''
+            a = str(a)
+            value = a
+        return value
 
 class PynagChoiceField(forms.MultipleChoiceField):
 
@@ -83,12 +150,20 @@ class PynagChoiceField(forms.MultipleChoiceField):
         """
         Takes a comma separated string, removes + if it is prefixed so. Returns a list
         """
+        if value is None:
+            return []
         if isinstance(value, str):
             self.attributelist = AttributeList(value)
             self.__prefix = self.attributelist.operator
             return self.attributelist.fields
-        return value
+        else:
+            raise ValueError("Expected string. Got %s" % type(value))
 
+    def set_prefix(self, value):
+        self.__prefix = value
+
+    def get_prefix(self):
+        return self.__prefix
 
 class PynagRadioWidget(forms.widgets.HiddenInput):
 
@@ -131,6 +206,14 @@ class PynagForm(AdagiosForm):
                 operator = AttributeList(self.pynag_object.get(k, '')).operator or ''
                 cleaned_data[k] = "%s%s" % (operator, v)
         return cleaned_data
+    @property
+    def changed_data(self):
+        # Fields that do not appear in our POST are not marked as changed data
+        # This can happen for example because some views decide not to print all
+        # Fields to the browser
+        changed_data = super(PynagForm, self).changed_data
+        changed_data = filter(lambda x: x in self.data, changed_data)
+        return changed_data
 
     def save(self):
         changed_keys = map(lambda x: smart_str(x), self.changed_data)
@@ -160,7 +243,6 @@ class PynagForm(AdagiosForm):
 
             # Here we actually make a change to our pynag object
             self.pynag_object[k] = value
-
             # Additionally, update the field for the return form
             self.fields[k] = self.get_pynagField(k, css_tag="defined")
             self.fields[k].value = value
@@ -168,14 +250,12 @@ class PynagForm(AdagiosForm):
         adagios.misc.rest.add_notification(message=_("Object successfully saved"), level="success", notification_type="show_once")
 
     def __init__(self, pynag_object, *args, **kwargs):
-        self.pynag_object = pynag_object
+        self.pynag_object = p = pynag_object
         super(PynagForm, self).__init__(*args, **kwargs)
         # Lets find out what attributes to create
         object_type = pynag_object['object_type']
-        defined_attributes = sorted(
-            self.pynag_object._defined_attributes.keys())
-        inherited_attributes = sorted(
-            self.pynag_object._inherited_attributes.keys())
+        defined_attributes = sorted(p._defined_attributes.keys())
+        inherited_attributes = sorted(p._inherited_attributes.keys())
         all_attributes = sorted(object_definitions.get(object_type).keys())
         all_attributes += ['name', 'use', 'register']
 
@@ -187,11 +267,9 @@ class PynagForm(AdagiosForm):
             # if field_name.startswith('$ARG'):
             #    self.fields[field_name] = self.get_pynagField(field_name, css_tag='defined')
             if object_type == 'service' and field_name.startswith('$_SERVICE'):
-                self.fields[field_name] = self.get_pynagField(
-                    field_name, css_tag='defined')
+                self.fields[field_name] = self.get_pynagField(field_name, css_tag='defined')
             elif object_type == 'host' and field_name.startswith('$_HOST'):
-                self.fields[field_name] = self.get_pynagField(
-                    field_name, css_tag='defined')
+                self.fields[field_name] = self.get_pynagField(field_name, css_tag='defined')
 
         # Calculate what attributes are "undefined"
         self.undefined_attributes = []
@@ -203,15 +281,22 @@ class PynagForm(AdagiosForm):
             self.undefined_attributes.append(i)
         # Find out which attributes to show
         for field_name in defined_attributes:
-            self.fields[field_name] = self.get_pynagField(
-                field_name, css_tag='defined')
+            self.fields[field_name] = self.get_pynagField(field_name, css_tag='defined')
         for field_name in inherited_attributes:
-            self.fields[field_name] = self.get_pynagField(
-                field_name, css_tag="inherited")
+            self.fields[field_name] = self.get_pynagField(field_name, css_tag="inherited")
         for field_name in self.undefined_attributes:
-            self.fields[field_name] = self.get_pynagField(
-                field_name, css_tag='undefined')
-        return
+            self.fields[field_name] = self.get_pynagField(field_name, css_tag='undefined')
+
+        # If no initial values were provided, use the one in our pynag object.
+        if not self.initial:
+            self.initial = pynag_object._defined_attributes
+            self.initial.update(pynag_object._changes)
+
+        for name, field in self.fields.items():
+            if name in self.initial:
+                field.initial = self.initial[name]
+            elif name in self.pynag_object:
+                field.initial = self.pynag_object[name]
 
     def get_pynagField(self, field_name, css_tag="", required=None):
         """ Takes a given field_name and returns a forms.Field that is appropriate for this field
@@ -233,48 +318,19 @@ class PynagForm(AdagiosForm):
         if False is True:
             pass
         elif field_name in ('contact_groups', 'contactgroups', 'contactgroup_members'):
-                all_groups = Model.Contactgroup.objects.filter(
-                    contactgroup_name__contains="")
-                choices = sorted(
-                    map(lambda x: (x.contactgroup_name, x.contactgroup_name), all_groups))
-                field = PynagChoiceField(
-                    choices=choices, inline_help_text=_("No %(field_name)s selected") % {'field_name': field_name})
+            field = PynagAutoCompleteField(object_type='contactgroup', complete='shortname')
         elif field_name == 'use':
-            all_objects = self.pynag_object.objects.filter(name__contains='')
-            choices = map(lambda x: (x.name, x.name), all_objects)
-            field = PynagChoiceField(
-                choices=sorted(choices), inline_help_text=_("No %s selected") % {'field_name': field_name})
+            field = PynagAutoCompleteField(object_type=object_type, complete="name")
         elif field_name in ('servicegroups', 'servicegroup_members'):
-            all_groups = Model.Servicegroup.objects.filter(
-                servicegroup_name__contains='')
-            choices = map(
-                lambda x: (x.servicegroup_name, x.servicegroup_name), all_groups)
-            field = PynagChoiceField(
-                choices=sorted(choices), inline_help_text=_("No %(field_name)s selected") % {'field_name': field_name})
+            field = PynagAutoCompleteField(object_type='servicegroup')
         elif field_name in ('hostgroups', 'hostgroup_members', 'hostgroup_name') and object_type != 'hostgroup':
-            all_groups = Model.Hostgroup.objects.filter(
-                hostgroup_name__contains='')
-            choices = map(
-                lambda x: (x.hostgroup_name, x.hostgroup_name), all_groups)
-            field = PynagChoiceField(
-                choices=sorted(choices), inline_help_text=_("No %(field_name)s selected") % {'field_name': field_name})
+            field = PynagAutoCompleteField(object_type='hostgroup')
         elif field_name == 'members' and object_type == 'hostgroup':
-            all_groups = Model.Host.objects.filter(host_name__contains='')
-            choices = map(lambda x: (x.host_name, x.host_name), all_groups)
-            field = PynagChoiceField(
-                choices=sorted(choices), inline_help_text=_("No %(field_name)s selected") % {'field_name': field_name})
+            field = PynagAutoCompleteField(object_type='host')
         elif field_name == 'host_name' and object_type == 'service':
-            all_groups = Model.Host.objects.filter(host_name__contains='')
-            choices = map(lambda x: (x.host_name, x.host_name), all_groups)
-            field = PynagChoiceField(
-                choices=sorted(choices), inline_help_text=_("No %(field_name)s selected") % {'field_name': field_name})
+            field = PynagAutoCompleteField(object_type='host')
         elif field_name in ('contacts', 'members'):
-            all_objects = Model.Contact.objects.filter(
-                contact_name__contains='')
-            choices = map(
-                lambda x: (x.contact_name, x.contact_name), all_objects)
-            field = PynagChoiceField(
-                choices=sorted(choices), inline_help_text=_("No %s selected") % {'field_name': field_name})
+            field = PynagAutoCompleteField(object_type='contact')
         elif field_name.endswith('_period'):
             all_objects = Model.Timeperiod.objects.filter(
                 timeperiod_name__contains='')
@@ -345,6 +401,8 @@ class PynagForm(AdagiosForm):
             field.widget.attrs['class'] = ''
             field.css_tag = ''
         field.widget.attrs['class'] += " " + css_tag
+        if not hasattr(field, 'css_tag'):
+            field.css_tag = ''
         field.css_tag += " " + css_tag
 
     def add_placeholder(self, field, placeholder=_("Insert some value here")):
