@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from django.conf.urls.defaults import *
+from django.conf.urls import url, patterns
 
 
 urlpatterns = patterns('adagios',
@@ -42,7 +42,6 @@ urlpatterns = patterns('adagios',
     url(r'^/add_to_group/(?P<group_type>.+)/(?P<group_name>.+)/?$', 'objectbrowser.views.add_to_group'),
     url(r'^/add_to_group/(?P<group_type>.+)/?$', 'objectbrowser.views.add_to_group'),
     url(r'^/add_to_group', 'objectbrowser.views.add_to_group'),
-    url(r'^/confighealth/?$', 'objectbrowser.views.config_health'),
     url(r'^/plugins/?$', 'objectbrowser.views.show_plugins'),
     url(r'^/nagios.cfg/?$', 'objectbrowser.views.edit_nagios_cfg'),
     url(r'^/nagios.cfg/edit/?$', 'misc.views.edit_nagios_cfg'),
