@@ -6,12 +6,12 @@
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
 # License, or (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Affero General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -37,12 +37,12 @@ MANAGERS = ADMINS
 
 DATABASES = {
     'default': {
-        'ENGINE': 'django.db.backends.sqlite3', # Add 'postgresql_psycopg2', 'postgresql', 'mysql', 'sqlite3' or 'oracle'.
-        'NAME': '/tmp/test',                      # Or path to database file if using sqlite3.
-        'USER': '',                      # Not used with sqlite3.
-        'PASSWORD': '',                  # Not used with sqlite3.
-        'HOST': '',                      # Set to empty string for localhost. Not used with sqlite3.
-        'PORT': '',                      # Set to empty string for default. Not used with sqlite3.
+        'ENGINE': 'django.db.backends.sqlite3',
+        'NAME': '/tmp/test',
+        'USER': '',
+        'PASSWORD': '',
+        'HOST': '',
+        'PORT': '',
     }
 }
 
@@ -72,14 +72,8 @@ USE_I18N = True
 USE_L10N = True
 
 
-# Absolute filesystem path to the directory that will hold user-uploaded files.
-# Example: "/home/media/media.lawrence.com/"
-MEDIA_ROOT = "%s/media/" % (djangopath)
-
-# URL that handles the media served from MEDIA_ROOT. Make sure to use a
-# trailing slash if there is a path component (optional in other cases).
-# Examples: "http://media.lawrence.com", "http://example.com/media/"
-MEDIA_URL = 'media/'
+STATIC_URL = '/media/'
+STATIC_ROOT = '%s/media/' % djangopath
 
 # URL prefix for admin media -- CSS, JavaScript and images. Make sure to use a
 # trailing slash.
@@ -93,7 +87,7 @@ TEMPLATE_LOADERS = (
 )
 
 MIDDLEWARE_CLASSES = (
-    #'django.contrib.sessions.middleware.SessionMiddleware',
+    'django.contrib.sessions.middleware.SessionMiddleware',
     'django.middleware.locale.LocaleMiddleware',
     'django.middleware.common.CommonMiddleware',
     'django.middleware.csrf.CsrfViewMiddleware',
@@ -102,6 +96,8 @@ MIDDLEWARE_CLASSES = (
     #'django.contrib.messages.middleware.MessageMiddleware',
 )
 
+SESSION_ENGINE = 'django.contrib.sessions.backends.signed_cookies'
+
 LANGUAGES = (
     ('en', 'English'),
     ('fr', 'French'),
@@ -123,13 +119,14 @@ TEMPLATE_DIRS = (
 INSTALLED_APPS = [
     #'django.contrib.auth',
     #'django.contrib.contenttypes',
-    #'django.contrib.sessions',
+    'django.contrib.sessions',
     'django.contrib.sites',
     #'django.contrib.messages',
     # Uncomment the next line to enable the admin:
     # 'django.contrib.admin',
     # Uncomment the next line to enable admin documentation:
     # 'django.contrib.admindocs',
+    #'django.contrib.staticfiles',
     'adagios.objectbrowser',
     'adagios.rest',
     'adagios.misc',
@@ -141,7 +138,7 @@ TEMPLATE_CONTEXT_PROCESSORS = ('adagios.context_processors.on_page_load',
     #"django.contrib.auth.context_processors.auth",
     "django.core.context_processors.debug",
     "django.core.context_processors.i18n",
-    "django.core.context_processors.media",
+    #"django.core.context_processors.media",
     "django.core.context_processors.static",
     "django.core.context_processors.request",
     "django.contrib.messages.context_processors.messages")
@@ -151,7 +148,7 @@ TEMPLATE_CONTEXT_PROCESSORS = ('adagios.context_processors.on_page_load',
 # To rapidly switch your theme, update THEME_DEFAULT and leave the rest.
 
 # folders in which themes files will be looked up
-THEMES_FOLDER = 'themes' # in 'media/'
+THEMES_FOLDER = 'themes'  # in 'media/'
 
 # default theme in use, it should be present in the THEMES_FOLDER
 # (or at least through a symbolic link)
@@ -160,75 +157,125 @@ THEME_DEFAULT = 'default'
 # CSS entry-point, in the theme folder
 THEME_ENTRY_POINT = 'style.css'
 
-# generated location of
-THEME_CSS = os.path.join(THEMES_FOLDER, THEME_DEFAULT, THEME_ENTRY_POINT)
+# folder where users preferences are stored
+USER_PREFS_PATH = "/var/lib/adagios/userdata/"
 
 
+# name displayed in the top left corner
+TOPMENU_HOME = 'Adagios'
+
+# items in the top menubar (excluding those coming from %s_menubar.html)
+# The identfier is used to recognize active links (which are displayed
+# differently).
+# The view can begin with '/' (and will go to http://server/...)
+# or can be a view name.
+# See Nagvis example for direct link, though the template contrib/nagvis.html must be created.
+TOPMENU_ITEMS = [
+    # Name,        identifier,      view_url,                                icon
+    # ('Nagvis',  'nagvis',        '/contrib/nagvis.html',                  'glyph-display'),
+    ('Configure', 'objectbrowser', 'objectbrowser.views.list_object_types', 'glyph-edit'),
+    ('Nagios',    'nagios',        'misc.views.nagios',                     'glyph-list'),
+
+]
+
+# Graphite #
+
+# the url where to fetch data and images
+graphite_url = "http://localhost:9091"
+
+# time ranges for generated graphs
+# the CSS identifier only needs to be unique here (it will be prefixed)
+GRAPHITE_PERIODS = [
+    # Displayed name, CSS identifier, Graphite period
+    ('4 hours',       'hours',        '-4h'),
+    ('One day',       'day',          '-1d'),
+    ('One week',      'week',         '-1w'),
+    ('One month',     'month',        '-1mon'),
+    ('One year',      'year',         '-1y'),
+    ]
+
+# querystring that will be passed on to graphite's render method.
+graphite_querystring = "target={host_}.{service_}.{metric_}&width=500&height=200&from={from_}d&lineMode=connected&title={title}&target={host_}.{service_}.{metric_}_warn&target={host_}.{service_}.{metric_}_crit"
+
+# Title format to use on all graphite graphs
+graphite_title = "{host} - {service} - {metric}"
+
+# default selected (active) tab, and the one rendered in General-preview
+GRAPHITE_DEFAULT_TAB = 'day'
+
 # Adagios specific configuration options. These are just the defaults,
 # Anything put in /etc/adagios.d/adagios.conf will overwrite this.
-nagios_config=None # Sensible default is "/etc/nagios/nagios.cfg"
-nagios_url="/nagios"
+nagios_config = None  # Sensible default is "/etc/nagios/nagios.cfg"
+nagios_url = "/nagios"
 nagios_init_script = "/etc/init.d/nagios"
 nagios_binary = "/usr/bin/nagios"
 livestatus_path = None
-enable_githandler=False
+enable_githandler = False
 enable_loghandler = False
 enable_authorization = False
 enable_status_view = True
 enable_bi = True
+enable_pnp4nagios = True
+enable_graphite = False
 contrib_dir = "/var/lib/adagios/contrib/"
 serverside_includes = "/etc/adagios/ssi"
 escape_html_tags = True
 warn_if_selinux_is_active = True
-destination_directory="/etc/nagios/adagios/"
-administrators="nagiosadmin,@users"
+destination_directory = "/etc/nagios/adagios/"
+administrators = "nagiosadmin,@users"
 pnp_url = "/pnp4nagios"
 pnp_filepath = "/usr/share/nagios/html/pnp4nagios/index.php"
-include=""
+include = ""
 django_secret_key = ""
 map_center = "64.119595,-21.655426"
 map_zoom = "10"
 title_prefix = "Adagios - "
 auto_reload = False
+refresh_rate = "30"
 
 plugins = {}
 
+# Profiling settings
+#
+# You can use the @profile("filename") to profile single functions within
+# adagios. Not enabled by default on any function.
+#
+# Documenations at
+# https://github.com/opinkerfi/adagios/wiki/Profiling-Decorators-within-Adagios
+PROFILE_LOG_BASE = "/var/lib/adagios"
+
 # Load config files from /etc/adagios
 # Adagios uses the configuration file in /etc/adagios/adagios.conf by default.
 # If it doesn't exist you should create it. Otherwise a adagios.conf will be
 # created in the django project root which should be avoided.
 adagios_configfile = "/etc/adagios/adagios.conf"
 
-# Try to save a configuration file into the project djangopath
-if not os.path.exists(adagios_configfile):
-    adagios_configfile = "%s/adagios.conf" % djangopath
-    open(adagios_configfile, "a").close()
 
 try:
+    if not os.path.exists(adagios_configfile):
+        alternative_adagios_configfile = "%s/adagios.conf" % djangopath
+        message = "Config file '{adagios_configfile}' not found. Using {alternative_adagios_configfile} instead."
+        warn(message.format(**locals()))
+        adagios_configfile = alternative_adagios_configfile
+        open(adagios_configfile, "a").close()
+
     execfile(adagios_configfile)
     # if config has any default include, lets include that as well
     configfiles = glob(include)
     for configfile in configfiles:
         execfile(configfile)
 except IOError, e:
-    # Only raise on errors other than file not found (missing config is OK)
-    if e.errno != 2:
-        raise Exception('Unable to open %s: %s' % (adagios_configfile, e.strerror))
-    # Warn on missing configs
-    else:
-        # TODO: Should this go someplace?
-        warn('Unable to open %s: %s' % (adagios_configfile, e.strerror))
+    warn('Unable to open %s: %s' % (adagios_configfile, e.strerror))
 
 try:
     from django.utils.crypto import get_random_string
 except ImportError:
-    def get_random_string(length, stringset=string.ascii_letters+string.digits+string.punctuation):
+    def get_random_string(length, stringset=string.ascii_letters + string.digits + string.punctuation):
         '''
         Returns a string with `length` characters chosen from `stringset`
         >>> len(get_random_string(20)) == 20
         '''
-        return ''.join([stringset[i%len(stringset)] \
-            for i in [ord(x) for x in os.urandom(length)]])
+        return ''.join([stringset[i % len(stringset)] for i in [ord(x) for x in os.urandom(length)]])
 
 if not django_secret_key:
     chars = 'abcdefghijklmnopqrstuvwxyz0123456789!@#$%^&*(-_=+)'
@@ -238,7 +285,7 @@ if not django_secret_key:
         with open(adagios_configfile, "a") as config_fh:
             config_fh.write(data)
     except Exception, e:
-        print("ERROR: Got %s while trying to save django secret_key in %s" % (type(e), adagios_configfile))
+        warn("ERROR: Got %s while trying to save django secret_key in %s" % (type(e), adagios_configfile))
 
 else:
     SECRET_KEY = django_secret_key
@@ -250,6 +297,12 @@ if enable_status_view:
 if enable_bi:
     plugins['bi'] = 'adagios.bi'
 
-for k,v in plugins.items():
-    INSTALLED_APPS.append( v )
+for k, v in plugins.items():
+    INSTALLED_APPS.append(v)
 
+# default preferences, for new users or when they are not available
+PREFS_DEFAULT = {
+    'language': 'en',
+    'theme': THEME_DEFAULT,
+    'refresh_rate': refresh_rate
+}
