@@ -8,12 +8,12 @@
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
 # License, or (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Affero General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -26,17 +26,32 @@ import os
 from django.test.client import RequestFactory
 import adagios.status
 import adagios.status.utils
+import adagios.status.graphite
+import adagios.settings
+import adagios.utils
+import simplejson as json
+
 
 class LiveStatusTestCase(unittest.TestCase):
 
-    def setUp(self):
-        from adagios.settings import nagios_config
-        self.nagios_config = nagios_config
-        self.factory = RequestFactory()
+    @classmethod
+    def setUpClass(cls):
+        cls.nagios_config = adagios.settings.nagios_config
+        cls.environment = adagios.utils.FakeAdagiosEnvironment()
+        cls.environment.create_minimal_environment()
+        cls.environment.configure_livestatus()
+        cls.environment.update_adagios_global_variables()
+        cls.environment.start()
+        cls.livestatus = cls.environment.get_livestatus()
+
+        cls.factory = RequestFactory()
+
+    @classmethod
+    def tearDownClass(cls):
+        cls.environment.terminate()
 
     def testLivestatusConnectivity(self):
-        livestatus = adagios.status.utils.livestatus(request=None)
-        requests = livestatus.query('GET status', 'Columns: requests')
+        requests = self.livestatus.query('GET status', 'Columns: requests')
         self.assertEqual(
             1, len(requests), _("Could not get status.requests from livestatus"))
 
@@ -74,18 +89,31 @@ class LiveStatusTestCase(unittest.TestCase):
         self.loadPage('/status/map')
         self.loadPage('/status/dashboard')
 
+    def test_status_detail(self):
+        """ Tests for /status/detail """
+        tmp = self.loadPage('/status/detail?contact_name=nagiosadmin')
+        self.assertTrue('nagiosadmin belongs to the following' in tmp.content)
+
+        tmp = self.loadPage('/status/detail?host_name=ok_host')
+        self.assertTrue('ok_host' in tmp.content)
+
+        tmp = self.loadPage('/status/detail?host_name=ok_host&service_description=ok%20service%201')
+        self.assertTrue('ok_host' in tmp.content)
+
+        tmp = self.loadPage('/status/detail?contactgroup_name=admins')
+        self.assertTrue('nagiosadmin' in tmp.content)
+
+        
     def testStateHistory(self):
         request = self.factory.get('/status/state_history')
         adagios.status.views.state_history(request)
 
-    def loadPage(self, url):
+    def loadPage(self, url, expected_status_code=200):
         """ Load one specific page, and assert if return code is not 200 """
-        try:
-            c = Client()
-            response = c.get(url)
-            self.assertEqual(response.status_code, 200, _("Expected status code 200 for page %s") % url)
-        except Exception, e:
-            self.assertEqual(True, _("Unhandled exception while loading %(url)s: %(e)s") % {'url': url, 'e': e})
+        c = Client()
+        response = c.get(url)
+        self.assertEqual(response.status_code, expected_status_code, _("Expected status code %(code)s for page %(url)s") % {'code': expected_status_code, 'url': url})
+        return response
 
     def testSubmitCommand(self):
         """ Test adagios.rest.status.submit_check_results
@@ -99,3 +127,47 @@ class LiveStatusTestCase(unittest.TestCase):
         data['performance_data'] = ''
         response = c.post('/rest/status/json/submit_check_result', data=data)
         self.assertEqual(200, response.status_code)
+
+    def test_rest_top_alert_producers(self):
+        """ Test adagios.rest.status.top_alert_producers
+        """
+        c = Client()
+        data = {}
+        data['limit'] = '1'
+        response = c.post('/rest/status/json/top_alert_producers', data=data)
+        self.assertEqual(200, response.status_code)
+
+        json_reply = json.loads(response.content)
+        self.assertFalse(len(json_reply) > 1, "Too many objects returned" \
+                         " limit is 1, json:\n" + str(json_reply))
+
+class Graphite(unittest.TestCase):
+    def test__get_graphite_url(self):
+        """ Smoketest for  adagios.status.graphite._get_graphite_url() """
+        base = "http://localhost/graphite"
+        host = "localhost"
+        service = "Ping"
+        metric = "packetloss"
+        from_ = "-1d"
+        parameters = locals()
+        parameters.pop('self', None)
+        result = adagios.status.graphite._get_graphite_url(**parameters)
+        self.assertTrue(result.startswith(base))
+        self.assertTrue(host in result)
+        self.assertTrue(service in result)
+        self.assertTrue(metric in result)
+
+    def test_get(self):
+        """ Smoketest for adagios.status.graphite.get() """
+        base = "http://localhost/graphite"
+        host = "localhost"
+        service = "Ping"
+        metrics = ["packetloss", "rta"]
+        units = [("test", "test", "-1d")]
+        parameters = locals()
+        parameters.pop('self', None)
+        result = adagios.status.graphite.get(**parameters)
+        self.assertTrue(result)
+        self.assertTrue(len(result) == 1)
+        self.assertTrue('rta' in result[0]['metrics'])
+        self.assertTrue('packetloss' in result[0]['metrics'])
