@@ -15,11 +15,11 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from django.conf.urls.defaults import *
+from django.conf.urls import url, patterns
 from django.conf import settings
 
 urlpatterns = patterns('adagios',
-                        url(r'^/?$', 'status.views.status_index', name="status_index"),
+                        url(r'^/?$', 'status.views.status_index'),
                         url(r'^/acknowledgements/?$', 'status.views.acknowledgement_list'),
                         url(r'^/error/?$', 'status.views.error_page'),
                         url(r'^/comments/?$', 'status.views.comment_list'),
@@ -39,6 +39,7 @@ urlpatterns = patterns('adagios',
                         url(r'^/servicegroups/?$', 'status.views.status_servicegroups'),
                         url(r'^/services/?$', 'status.views.services'),
                         url(r'^/state_history/?$', 'status.views.state_history'),
+                        url(r'^/backends/?$', 'status.views.backends'),
 
 
 
