@@ -45,6 +45,7 @@ import adagios.status.rest
 import adagios.status.forms
 import adagios.businessprocess
 from django.core.urlresolvers import reverse
+from adagios.status import graphite
 
 state = defaultdict(lambda: "unknown")
 state[0] = "ok"
@@ -57,24 +58,26 @@ from adagios.views import adagios_decorator, error_page
 @adagios_decorator
 def detail(request):
     """ Return status detail view for a single given host, hostgroup,service, contact, etc """
-    host_name = request.GET.get('host_name')
-    service_description = request.GET.get('service_description')
-    contact_name = request.GET.get('contact_name')
-    hostgroup_name = request.GET.get('hostgroup_name')
-    contactgroup_name = request.GET.get('contactgroup_name')
-    servicegroup_name = request.GET.get('servicegroup_name')
-    if service_description:
-        return service_detail(request, host_name=host_name, service_description=service_description)
-    elif host_name:
-        return host_detail(request, host_name=host_name)
-    elif contact_name:
-        return contact_detail(request, contact_name=contact_name)
-    elif contactgroup_name:
-        return contactgroup_detail(request, contactgroup_name=contactgroup_name)
-    elif hostgroup_name:
-        return hostgroup_detail(request, hostgroup_name=hostgroup_name)
-    elif servicegroup_name:
-        return servicegroup_detail(request, servicegroup_name=servicegroup_name)
+    args = {}
+    for query_parm in ['host_name', 'service_description', 'contact_name',
+              'hostgroup_name', 'contactgroup_name', 'servicegroup_name']:
+        value = request.GET.get(query_parm)
+        if value:
+            args[query_parm] = value.encode('utf-8')
+
+    if 'service_description' in args:
+        return service_detail(request, host_name=args['host_name'],
+                                       service_description=args['service_description'])
+    elif 'host_name' in args:
+        return host_detail(request, host_name=args['host_name'])
+    elif 'contact_name' in args:
+        return contact_detail(request, contact_name=args['contact_name'])
+    elif 'contactgroup_name' in args:
+        return contactgroup_detail(request, contactgroup_name=args['contactgroup_name'])
+    elif 'hostgroup_name' in args:
+        return hostgroup_detail(request, hostgroup_name=args['hostgroup_name'])
+    elif 'servicegroup_name' in args:
+        return servicegroup_detail(request, servicegroup_name=args['servicegroup_name'])
 
     raise Exception(_("You have to provide an item via querystring so we know what to give you details for"))
 
@@ -249,6 +252,7 @@ def service_detail(request, host_name, service_description):
     c['errors'] = []
 
     livestatus = utils.livestatus(request)
+    backend = request.GET.get('backend')
     c['pnp_url'] = adagios.settings.pnp_url
     c['nagios_url'] = adagios.settings.nagios_url
     c['request'] = request
@@ -258,7 +262,7 @@ def service_detail(request, host_name, service_description):
     today = now - seconds_passed_today  # midnight of today
 
     try:
-        c['host'] = my_host = livestatus.get_host(host_name)
+        c['host'] = my_host = livestatus.get_host(host_name, backend)
         my_host['object_type'] = 'host'
         my_host['short_name'] = my_host['name']
     except IndexError:
@@ -276,7 +280,7 @@ def service_detail(request, host_name, service_description):
     else:
         try:
             c['service'] = my_service = livestatus.get_service(
-                host_name, service_description)
+                host_name, service_description, backend=backend)
             my_service['object_type'] = 'service'
             c['service_description'] = service_description
             my_service['short_name'] = "%s/%s" % (
@@ -314,7 +318,7 @@ def service_detail(request, host_name, service_description):
         except pynag.Utils.PynagError:
             datum.status = state[3]
     c['perfdata'] = perfdata.metrics
-
+    
     # Get a complete list of network parents
     try:
         c['network_parents'] = reversed(_get_network_parents(request, host_name))
@@ -322,14 +326,32 @@ def service_detail(request, host_name, service_description):
         c['errors'].append(e)
 
     # Lets get some graphs
-    try:
-        tmp = run_pnp("json", host=host_name)
-        tmp = json.loads(tmp)
-    except Exception, e:
-        tmp = []
-        c['pnp4nagios_error'] = e
-    c['graph_urls'] = tmp
-
+    if adagios.settings.enable_pnp4nagios:
+        try:
+            tmp = run_pnp("json", host=host_name)
+            tmp = json.loads(tmp)
+        except Exception, e:
+            tmp = []
+            c['pnp4nagios_error'] = e
+        c['graph_urls'] = tmp
+    
+    if adagios.settings.enable_graphite:
+        metrics = [x.label for x in perfdata.metrics]
+        service = c['service_description'].replace(' ', '_')
+        c['graphite'] = graphite.get(adagios.settings.graphite_url,
+                                     c['host_name'],
+                                     service,
+                                     metrics,
+                                     adagios.settings.GRAPHITE_PERIODS,
+                                     )
+        # used in the General tab - preview
+        for graph in c['graphite']:
+            if graph['css_id'] == adagios.settings.GRAPHITE_DEFAULT_TAB:
+                default = {}
+                for k,v in graph['metrics'].items():
+                    default[k] = v
+                c['graphite_default'] = default
+    
     return render_to_response('status_detail.html', c, context_instance=RequestContext(request))
 
 
@@ -349,12 +371,13 @@ def _get_network_parents(request, host_name):
         ]
     """
     result = []
+    backend = request.GET.get('backend', None)
     livestatus = adagios.status.utils.livestatus(request)
     if isinstance(host_name, unicode):
         host_name = smart_str(host_name)
 
     if isinstance(host_name, str):
-        host = livestatus.get_host(host_name)
+        host = livestatus.get_host(host_name, backend)
     elif isinstance(host_name, dict):
         host = host_name
     else:
@@ -362,7 +385,7 @@ def _get_network_parents(request, host_name):
             'host_name must be str or dict (got %s)' % type(host_name))
     parent_names = host['parents']
     while len(parent_names) > 0:
-        parents = map(lambda x: livestatus.get_host(x), parent_names)
+        parents = map(lambda x: livestatus.get_host(x, backend), parent_names)
 
         # generate a list of grandparent names:
         grand_parents = set()
@@ -1001,16 +1024,14 @@ def contact_detail(request, contact_name):
     c['errors'] = []
     c['contact_name'] = contact_name
     l = adagios.status.utils.livestatus(request)
+    backend = request.GET.get('backend', None)
 
     # Fetch contact and basic information
-    result = l.query("GET contacts", "Filter: name = %s" % contact_name)
-    if result == []:
-        c['errors'].append("Contact named '%s' was not found." % contact_name)
-        if contact_name != 'anonymous':
-            return render_to_response('status_error.html', c, context_instance=RequestContext(request))
-    else:
-        contact = result[0]
+    try:
+        contact = l.get_contact(contact_name, backend)
         c['contact'] = contact
+    except IndexError:
+        raise Exception("Contact named '%s' was not found." % contact_name)
 
     # Active comments
     c['comments'] = l.query(
@@ -1181,7 +1202,17 @@ def status_hostgroup(request, hostgroup_name):
     """ Here for backwards compatibility """
     return hostgroup_detail(request, hostgroup_name=hostgroup_name)
 
+
 @adagios_decorator
 def status_detail(request):
     """ Here for backwards compatibility """
     return detail(request)
+
+@adagios_decorator
+def backends(request):
+    """ Display a list of available backends and their connection status """
+    livestatus = adagios.status.utils.livestatus(request)
+    backends = livestatus.get_backends()
+    for i, v in backends.items():
+        v.test(raise_error=False)
+    return render_to_response('status_backends.html', locals(), context_instance=RequestContext(request))
